@@ -10,9 +10,11 @@ class sqlserver():
             cursor = conn.cursor()
             cursor.execute(Query)
             cursor.commit()
-            print("Query Executed")
+	    print('Query Passed!')
+            return True
         except Exception as e:
-            print(e)
+	    print(e)
+            return False
     def fields(self, cur):
         results = {}
         column = 0
